@@ -40,6 +40,18 @@ BOOL hexoffset=TRUE;
 
 static int ViewFile(DirEntry * dir_entry, char *file_path);
 static int ViewArchiveFile(char *file_path);
+static void hex_edit(char *file_path);
+static void printhexline(WINDOW *win, char *line, char *buf, int r, long offset);
+static void update_line(WINDOW *win, long line);
+static void scroll_down(WINDOW *win);
+static void scroll_up(WINDOW *win);
+static void update_all_lines(WINDOW *win, char l);
+static void Change2Edit(char *file_path);
+static void Change2View(char *file_path);
+static void SetupViewWindow(char *file_path);
+static unsigned char hexval(unsigned char v);
+static void change_char(int ch);
+static void move_right(WINDOW *win);
 
 
 
@@ -257,16 +269,18 @@ static int ViewArchiveFile(char *file_path)
 
 
 
-char *strn2print(char *dest, char *src, int c)
+/*
+static char *strn2print(char *dest, char *src, int c)
 {
     dest[c]='\0';
     for( ;c >= 0;c--)
 	dest[c] = (isprint(src[c]) ? src[c] : '.');
     return dest;
 }
+*/
 
 
-void printhexline(WINDOW *win, char *line, char *buf, int r, long offset)
+static void printhexline(WINDOW *win, char *line, char *buf, int r, long offset)
 {
     char *aux;
     int i;
@@ -309,7 +323,7 @@ void printhexline(WINDOW *win, char *line, char *buf, int r, long offset)
     return;
 }
 
-void update_line(WINDOW *win, long line)
+static void update_line(WINDOW *win, long line)
 {
     int r;
     char *buf;
@@ -334,7 +348,7 @@ void update_line(WINDOW *win, long line)
     xfree(buf);
 }
 
-void scroll_down(WINDOW *win)
+static void scroll_down(WINDOW *win)
 {
     scrollok(win,TRUE);
     wscrl(win,1);
@@ -345,7 +359,7 @@ void scroll_down(WINDOW *win)
     doupdate();    
 }
 
-void scroll_up(WINDOW *win)
+static void scroll_up(WINDOW *win)
 {
     scrollok(win,TRUE);
     wscrl(win,-1);
@@ -356,7 +370,7 @@ void scroll_up(WINDOW *win)
     doupdate();    
 }
 
-void update_all_lines(WINDOW *win, char l)
+static void update_all_lines(WINDOW *win, char l)
 {
     long i;
 
@@ -370,7 +384,7 @@ void update_all_lines(WINDOW *win, char l)
 }
 
 
-void Change2Edit(char *file_path)
+static void Change2Edit(char *file_path)
 {
     int i;
     char *str;
@@ -394,7 +408,7 @@ void Change2Edit(char *file_path)
     return;
 }
 
-void Change2View(char *file_path)
+static void Change2View(char *file_path)
 {
     int i;
     char *str;
@@ -417,7 +431,7 @@ void Change2View(char *file_path)
     return;
 }
 
-void SetupViewWindow(char *file_path)
+static void SetupViewWindow(char *file_path)
 {
     int i;
     char *str;
@@ -456,7 +470,7 @@ void SetupViewWindow(char *file_path)
 
 
 
-unsigned char hexval(unsigned char v) {
+static unsigned char hexval(unsigned char v) {
 	if (v >= 'a' && v <= 'f')
 		v = v - 'a' + 10;
 	else if (v >= '0' && v <= '9')
@@ -465,7 +479,7 @@ unsigned char hexval(unsigned char v) {
 }
 
 
-void change_char(int ch)
+static void change_char(int ch)
 {
 
     CHANGES *cambio=NULL;
@@ -537,7 +551,7 @@ void change_char(int ch)
 }
 
 
-void move_right(WINDOW *win)
+static void move_right(WINDOW *win)
 {
    fstat(fd,&fdstat);
    cursor_pos_x++;
@@ -568,7 +582,7 @@ void move_right(WINDOW *win)
     return;
 }
 
-void hex_edit(char *file_path)
+static void hex_edit(char *file_path)
 {
     int ch;
     char mensaje[50];
